@@ -815,6 +815,9 @@ class ERA:
         data with the reduced model based on the modes which are kept
         for consideration.
         """
+        if len(selected_modes) == 0:
+            raise RuntimeError("No modes selected")
+
         if saved_model:
             freq = self._saved["freqs_hz"]
             zeta = self._saved["zeta"]
@@ -1125,7 +1128,7 @@ class ERA:
                 input_string = (
                     input(
                         "\nSelect modes for ERA fit (to keep or remove):\n"
-                        "\t- 'Enter' or '*' to keep marked modes\n"
+                        "\t- <Enter> or '*' to keep marked modes\n"
                         "\t- 'a' to keep all modes\n"
                         "\t- mode #s separated by space and/or comma (eg: 1, 2, 5)\n"
                     )
